==> loadmychunks-1.2.0%2B1.21.1%2Bfabric-sources.jar: com/drathonix/loadmychunks/common/registry/FakeRegistrySupplier.java <==
package com.drathonix.loadmychunks.common.registry;

import java.util.function.Supplier;

//? if >1.16.5 {
import com.mojang.datafixers.util.Either;
import dev.architectury.registry.registries.RegistrySupplier;
import dev.architectury.registry.registries.Registrar;
//? if <1.19.3
/*import dev.architectury.registry.registries.Registries;*/
//? if >1.19.3
import dev.architectury.registry.registries.RegistrarManager;
import java.util.Optional;
import java.util.function.Predicate;
import java.util.stream.Stream;
//?}
import net.minecraft.class_2960;
import net.minecraft.class_5321;
import net.minecraft.class_6862;
import net.minecraft.class_6880;
import net.minecraft.class_7876;

/**
 * Used to instantiate architectury registry suppliers in older versions. Merely used for versioning simplification
 * @since 1.0.0
 * @author Jack Andersen
 */
@SuppressWarnings("NonExtendableApiUsage")
public class FakeRegistrySupplier<T> implements RegistrySupplier<T> {
    private final Supplier<T> supplier;
    private T t;

    public FakeRegistrySupplier(T t) {
        this.supplier = () -> t;
    }
    public FakeRegistrySupplier(Supplier<T> supplier) {
        this.supplier=supplier;
    }

    @Override
    public class_2960 getRegistryId() {
        return null;
    }

    @Override
    public class_2960 getId() {
        return null;
    }

    @Override
    public boolean isPresent() {
        return false;
    }

    @Override
    public T get() {
        if(t==null) {
            t=supplier.get();
        }
        return t;
    }

    //? if >1.19.3 {
    @Override
    public RegistrarManager getRegistrarManager() {
        return null;
    }
    //?}

    //? if <1.19.3 && >1.16.5 {
    /*@Override
    public Registries getRegistries() {
        return null;
    }
    *///?}

    //? if >1.16.5 {
    @Override
    public Registrar<T> getRegistrar() {
        return null;
    }
    //?}

    //? if >1.20.3 {
    @Override
    public T comp_349() {
        return null;
    }

    @Override
    public boolean method_40227() {
        return false;
    }

    @Override
    public boolean method_40226(class_2960 resourceLocation) {
        return false;
    }

    @Override
    public boolean method_40225(class_5321<T> resourceKey) {
        return false;
    }

    @Override
    public boolean method_40224(Predicate<class_5321<T>> predicate) {
        return false;
    }

    @Override
    public boolean method_40220(class_6862<T> tagKey) {
        return false;
    }

    //? if >1.20.5 {
    @Override
    public boolean method_55838(class_6880<T> holder) {
        return false;
    }
    //?}

    @Override
    public Stream<class_6862<T>> method_40228() {
        return Stream.empty();
    }

    @Override
    public Either<class_5321<T>, T> method_40229() {
        return null;
    }

    @Override
    public Optional<class_5321<T>> method_40230() {
        return Optional.empty();
    }

    @Override
    public class_6882 method_40231() {
        return null;
    }

    @Override
    public boolean method_46745(class_7876<T> holderOwner) {
        return false;
    }
    //?}

    //? if >1.20.6 && neoforge {
    /*public ResourceKey<T> getKey() {
        return ResourceKey.create(getRegistryKey(), getId());
    }
    *///?}
}

==> loadmychunks-1.2.1%2B1.19.2%2Bfabric-sources.jar: com/drathonix/loadmychunks/common/registry/FakeRegistrySupplier.java <==
package com.drathonix.loadmychunks.common.registry;

import java.util.function.Supplier;
import net.minecraft.class_2960;
//? if >1.16.5 {
import com.mojang.datafixers.util.Either;
import dev.architectury.registry.registries.RegistrySupplier;
import dev.architectury.registry.registries.Registrar;
//? if <1.19.3
import dev.architectury.registry.registries.Registries;
//? if >1.19.3
/*import dev.architectury.registry.registries.RegistrarManager;*/
//?}
//? if >1.20.3 {
/*import net.minecraft.core.HolderOwner;
import net.minecraft.resources.ResourceKey;
import net.minecraft.tags.TagKey;

import java.util.Optional;
import java.util.function.Predicate;
import java.util.stream.Stream;
*///?}

/**
 * Used to instantiate architectury registry suppliers in older versions. Merely used for versioning simplification
 * @since 1.0.0
 * @author Jack Andersen
 */
@SuppressWarnings("NonExtendableApiUsage")
public class FakeRegistrySupplier<T> implements RegistrySupplier<T> {
    private final Supplier<T> supplier;
    private T t;

    public FakeRegistrySupplier(T t) {
        this.supplier = () -> t;
    }
    public FakeRegistrySupplier(Supplier<T> supplier) {
        this.supplier=supplier;
    }

    @Override
    public class_2960 getRegistryId() {
        return null;
    }

    @Override
    public class_2960 getId() {
        return null;
    }

    @Override
    public boolean isPresent() {
        return false;
    }

    @Override
    public T get() {
        if(t==null) {
            t=supplier.get();
        }
        return t;
    }

    //? if >1.19.3 {
    /*@Override
    public RegistrarManager getRegistrarManager() {
        return null;
    }
    *///?}

    //? if <1.19.3 && >1.16.5 {
    @Override
    public Registries getRegistries() {
        return null;
    }
    //?}

    //? if >1.16.5 {
    @Override
    public Registrar<T> getRegistrar() {
        return null;
    }
    //?}

    //? if >1.20.3 {
    /*@Override
    public T value() {
        return null;
    }

    @Override
    public boolean isBound() {
        return false;
    }

    @Override
    public boolean is(ResourceLocation resourceLocation) {
        return false;
    }

    @Override
    public boolean is(ResourceKey<T> resourceKey) {
        return false;
    }

    @Override
    public boolean is(Predicate<ResourceKey<T>> predicate) {
        return false;
    }

    @Override
    public boolean is(TagKey<T> tagKey) {
        return false;
    }

    //? if >1.20.5 {
    /^@Override
    public boolean is(Holder<T> holder) {
        return false;
    }
    ^///?}

    @Override
    public Stream<TagKey<T>> tags() {
        return Stream.empty();
    }

    @Override
    public Either<ResourceKey<T>, T> unwrap() {
        return null;
    }

    @Override
    public Optional<ResourceKey<T>> unwrapKey() {
        return Optional.empty();
    }

    @Override
    public Kind kind() {
        return null;
    }

    @Override
    public boolean canSerializeIn(HolderOwner<T> holderOwner) {
        return false;
    }
    *///?}

    //? if >1.20.6 && neoforge {
    /*public ResourceKey<T> getKey() {
        return ResourceKey.create(getRegistryKey(), getId());
    }
    *///?}
}
